@@ -223,7 +223,7 @@ use Scalar::Util ();
 use AnyEvent ();
 use AnyEvent::Util ();
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub OBSID() { 0x10000000000000 } # 2**52
 
@@ -398,7 +398,7 @@ sub start {
 
    $self->{fh} = $fh;
 
-   my $trace = delete $self->{trace} || sub { };
+   my $trace = $self->{trace} || sub { };
 
    $trace = sub { warn "$_[0] $_[1]\n" } if $trace && !ref $trace;
 
